@@ -55,7 +55,7 @@ representers = {
 
 
 def save_text(string: str, path: str, encoding: str = "utf-8") -> None:
-    """Save text string to file
+    """Save text string to file.
 
     Args:
         string (str): String to save
@@ -76,7 +76,7 @@ def save_yaml(
     pretty: bool = False,
     sortkeys: bool = False,
 ) -> None:
-    """Save dictionary to YAML file preserving order if it is an OrderedDict
+    """Save dictionary to YAML file preserving order if it is an OrderedDict.
 
     Args:
         object (Any): Python object to save
@@ -112,7 +112,7 @@ def save_json(
     pretty: bool = False,
     sortkeys: bool = False,
 ) -> None:
-    """Save dictionary to JSON file preserving order if it is an OrderedDict
+    """Save dictionary to JSON file preserving order if it is an OrderedDict.
 
     Args:
         object (Any): Python object to save
@@ -148,12 +148,12 @@ def save_hxlated_output(
     output_dir: str = "",
     **kwargs: Any,
 ) -> None:
-    """Save rows with header and HXL hashtags. Currently, JSON and/or csv outputs are
-    supported. An output directory (which defaults to "") can be given. The utility
-    expects a configuration containing definitions of input headers and HXLtags if
-    these are not included in the rows, and output files with desired HXL hashtags.
-    Keyword arguments are used to pass in any variables needed by the metadata defined
-    in the configuration.
+    """Save rows with header and HXL hashtags. Currently, JSON and/or csv
+    outputs are supported. An output directory (which defaults to "") can be
+    given. The utility expects a configuration containing definitions of input
+    headers and HXLtags if these are not included in the rows, and output files
+    with desired HXL hashtags. Keyword arguments are used to pass in any
+    variables needed by the metadata defined in the configuration.
 
     Args:
         configuration (Dict): Configuration for input and output
@@ -184,8 +184,8 @@ def save_hxlated_output(
             rows = rows[1:]
     else:
         hxltags = configuration["input"]["hxltags"]
-    expressions = dict()
-    for process in configuration.get("process", list()):
+    expressions = {}
+    for process in configuration.get("process", []):
         headers.append(process["header"])
         hxltag = process["hxltag"]
         hxltags.append(hxltag)
@@ -214,7 +214,7 @@ def save_hxlated_output(
         json_hxltags = json_configuration.get("hxltags", hxltags)
         metadata_configuration = json_configuration.get("metadata")
         if metadata_configuration:
-            metadata = dict()
+            metadata = {}
             for metadata_name, value in metadata_configuration.items():
                 if isinstance(value, str):
                     template_string, match_string = match_template_variables(
@@ -256,7 +256,7 @@ def save_hxlated_output(
             inrow = list(inrow.values())
 
         def get_outrow(file_hxltags):
-            outrow = dict()
+            outrow = {}
             for file_hxltag in file_hxltags:
                 expression = expressions.get(file_hxltag)
                 if expression:
