@@ -73,6 +73,18 @@ class TestDownloader:
     def fixtureprocessurlblank(self):
         return "https://raw.githubusercontent.com/OCHA-DAP/hdx-python-utilities/main/tests/fixtures/downloader/test_csv_processing_blanks.csv?a=1"
 
+    @pytest.fixture(scope="class")
+    def fixturexlsurl(self):
+        return "https://raw.githubusercontent.com/OCHA-DAP/hdx-python-utilities/main/tests/fixtures/downloader/test_xls_processing.xls?a=1"
+
+    @pytest.fixture(scope="class")
+    def fixturexlsxurl(self):
+        return "https://raw.githubusercontent.com/OCHA-DAP/hdx-python-utilities/main/tests/fixtures/downloader/test_xlsx_processing.xlsx?a=1"
+
+    @pytest.fixture(scope="class")
+    def fixturejsonurl(self):
+        return "https://raw.githubusercontent.com/OCHA-DAP/hdx-python-utilities/main/tests/fixtures/downloader/test_json_processing.json?a=1"
+
     def test_get_path_for_url(
         self, tmpdir, fixtureurl, configfolder, downloaderfolder
     ):
@@ -364,12 +376,23 @@ class TestDownloader:
                 fixtureurl, folder=tmpdir, filename=filename
             )
             fpath = abspath(f)
-            remove(f)
             assert fpath == abspath(join(tmpdir, filename))
             f = downloader.download_file(
                 fixtureurl, path=join(tmpdir, filename), overwrite=True
             )
             fpath = abspath(f)
+            assert fpath == abspath(join(tmpdir, filename))
+            f = downloader.download_file(
+                fixtureurl, path=join(tmpdir, filename), overwrite=False
+            )
+            fpath = abspath(f)
+            assert fpath == abspath(
+                join(tmpdir, filename.replace(".txt", "1.txt"))
+            )
+            f = downloader.download_file(
+                fixtureurl, path=join(tmpdir, filename), keep=True
+            )
+            fpath = abspath(f)
             remove(f)
             assert fpath == abspath(join(tmpdir, filename))
             f = downloader.download_file(
@@ -734,6 +757,412 @@ class TestDownloader:
             with pytest.raises(DownloadError):
                 downloader.get_tabular_rows(fixtureprocessurl, headers=None)
 
+    def test_get_tabular_rows_xls(self, fixturexlsurl):
+        with Download() as downloader:
+            headers, iterator = downloader.get_tabular_rows(
+                fixturexlsurl, format="xls", headers=4
+            )
+            assert headers == [
+                "Country Name",
+                "Country Code",
+                "Indicator Name",
+                "Indicator Code",
+                "Year",
+                "Value",
+            ]
+            rows = list(iterator)
+            assert rows[0] == [
+                "Aruba",
+                "ABW",
+                "Population, total",
+                "SP.POP.TOTL",
+                1960,
+                54211,
+            ]
+            assert rows[-1] == [
+                "Zimbabwe",
+                "ZWE",
+                "Population, total",
+                "SP.POP.TOTL",
+                2019,
+                14645468,
+            ]
+
+    def test_get_tabular_rows_xlsx(self, fixturexlsxurl):
+        with Download() as downloader:
+            headers, iterator = downloader.get_tabular_rows(
+                fixturexlsxurl, format="xlsx", sheet="Trend", headers=[7, 8]
+            )
+            assert headers[1:222] == [
+                "ISO",
+                "Countries and areas",
+                "UNICEF Regions",
+                "UN Regions",
+                "WHO Regions",
+                "World Bank Income Groups",
+                "Survey Years",
+                "Year*",
+                "Short Source",
+                "Full Source Title",
+                "Latest Estimate",
+                "Estimate Type",
+                "National Point Estimate",
+                "National Lower Limit",
+                "National Upper Limit",
+                "National Sample Size",
+                "National Footnote",
+                "Region 1 Point Estimate",
+                "Region 1 Lower Limit",
+                "Region 1 Upper Limit",
+                "Region 1 Sample Size",
+                "Region 1 Region Name",
+                "Region 1 Footnote",
+                "Region 2 Point Estimate",
+                "Region 2 Lower Limit",
+                "Region 2 Upper Limit",
+                "Region 2 Sample Size",
+                "Region 2 Region Name",
+                "Region 2 Footnote",
+                "Region 3 Point Estimate",
+                "Region 3 Lower Limit",
+                "Region 3 Upper Limit",
+                "Region 3 Sample Size",
+                "Region 3 Region Name",
+                "Region 3 Footnote",
+                "Region 4 Point Estimate",
+                "Region 4 Lower Limit",
+                "Region 4 Upper Limit",
+                "Region 4 Sample Size",
+                "Region 4 Region Name",
+                "Region 4 Footnote",
+                "Region 5 Point Estimate",
+                "Region 5 Lower Limit",
+                "Region 5 Upper Limit",
+                "Region 5 Sample Size",
+                "Region 5 Region Name",
+                "Region 5 Footnote",
+                "Region 6 Point Estimate",
+                "Region 6 Lower Limit",
+                "Region 6 Upper Limit",
+                "Region 6 Sample Size",
+                "Region 6 Region Name",
+                "Region 6 Footnote",
+                "Region 7 Point Estimate",
+                "Region 7 Lower Limit",
+                "Region 7 Upper Limit",
+                "Region 7 Sample Size",
+                "Region 7 Region Name",
+                "Region 7 Footnote",
+                "Region 8 Point Estimate",
+                "Region 8 Lower Limit",
+                "Region 8 Upper Limit",
+                "Region 8 Sample Size",
+                "Region 8 Region Name",
+                "Region 8 Footnote",
+                "Region 9 Point Estimate",
+                "Region 9 Lower Limit",
+                "Region 9 Upper Limit",
+                "Region 9 Sample Size",
+                "Region 9 Region Name",
+                "Region 9 Footnote",
+                "Region 10 Point Estimate",
+                "Region 10 Lower Limit",
+                "Region 10 Upper Limit",
+                "Region 10 Sample Size",
+                "Region 10 Region Name",
+                "Region 10 Footnote",
+                "Region 11 Point Estimate",
+                "Region 11 Lower Limit",
+                "Region 11 Upper Limit",
+                "Region 11 Sample Size",
+                "Region 11 Region Name",
+                "Region 11 Footnote",
+                "Region 12 Point Estimate",
+                "Region 12 Lower Limit",
+                "Region 12 Upper Limit",
+                "Region 12 Sample Size",
+                "Region 12 Region Name",
+                "Region 12 Footnote",
+                "Region 13 Point Estimate",
+                "Region 13 Lower Limit",
+                "Region 13 Upper Limit",
+                "Region 13 Sample Size",
+                "Region 13 Region Name",
+                "Region 13 Footnote",
+                "Region 14 Point Estimate",
+                "Region 14 Lower Limit",
+                "Region 14 Upper Limit",
+                "Region 14 Sample Size",
+                "Region 14 Region Name",
+                "Region 14 Footnote",
+                "Region 15 Point Estimate",
+                "Region 15 Lower Limit",
+                "Region 15 Upper Limit",
+                "Region 15 Sample Size",
+                "Region 15 Region Name",
+                "Region 15 Footnote",
+                "Region 16 Point Estimate",
+                "Region 16 Lower Limit",
+                "Region 16 Upper Limit",
+                "Region 16 Sample Size",
+                "Region 16 Region Name",
+                "Region 16 Footnote",
+                "Region 17 Point Estimate",
+                "Region 17 Lower Limit",
+                "Region 17 Upper Limit",
+                "Region 17 Sample Size",
+                "Region 17 Region Name",
+                "Region 17 Footnote",
+                "Region 18 Point Estimate",
+                "Region 18 Lower Limit",
+                "Region 18 Upper Limit",
+                "Region 18 Sample Size",
+                "Region 18 Region Name",
+                "Region 18 Footnote",
+                "Region 19 Point Estimate",
+                "Region 19 Lower Limit",
+                "Region 19 Upper Limit",
+                "Region 19 Sample Size",
+                "Region 19 Region Name",
+                "Region 19 Footnote",
+                "Region 20 Point Estimate",
+                "Region 20 Lower Limit",
+                "Region 20 Upper Limit",
+                "Region 20 Sample Size",
+                "Region 20 Region Name",
+                "Region 20 Footnote",
+                "Region 21 Point Estimate",
+                "Region 21 Lower Limit",
+                "Region 21 Upper Limit",
+                "Region 21 Sample Size",
+                "Region 21 Region Name",
+                "Region 21 Footnote",
+                "Region 22 Point Estimate",
+                "Region 22 Lower Limit",
+                "Region 22 Upper Limit",
+                "Region 22 Sample Size",
+                "Region 22 Region Name",
+                "Region 22 Footnote",
+                "Region 23 Point Estimate",
+                "Region 23 Lower Limit",
+                "Region 23 Upper Limit",
+                "Region 23 Sample Size",
+                "Region 23 Region Name",
+                "Region 23 Footnote",
+                "Region 24 Point Estimate",
+                "Region 24 Lower Limit",
+                "Region 24 Upper Limit",
+                "Region 24 Sample Size",
+                "Region 24 Region Name",
+                "Region 24 Footnote",
+                "Region 25 Point Estimate",
+                "Region 25 Lower Limit",
+                "Region 25 Upper Limit",
+                "Region 25 Sample Size",
+                "Region 25 Region Name",
+                "Region 25 Footnote",
+                "Region 26 Point Estimate",
+                "Region 26 Lower Limit",
+                "Region 26 Upper Limit",
+                "Region 26 Sample Size",
+                "Region 26 Region Name",
+                "Region 26 Footnote",
+                "Region 27 Point Estimate",
+                "Region 27 Lower Limit",
+                "Region 27 Upper Limit",
+                "Region 27 Sample Size",
+                "Region 27 Region Name",
+                "Region 27 Footnote",
+                "Region 28 Point Estimate",
+                "Region 28 Lower Limit",
+                "Region 28 Upper Limit",
+                "Region 28 Sample Size",
+                "Region 28 Region Name",
+                "Region 28 Footnote",
+                "Region 29 Point Estimate",
+                "Region 29 Lower Limit",
+                "Region 29 Upper Limit",
+                "Region 29 Sample Size",
+                "Region 29 Region Name",
+                "Region 29 Footnote",
+                "Region 30 Point Estimate",
+                "Region 30 Lower Limit",
+                "Region 30 Upper Limit",
+                "Region 30 Sample Size",
+                "Region 30 Region Name",
+                "Region 30 Footnote",
+                "Region 31 Point Estimate",
+                "Region 31 Lower Limit",
+                "Region 31 Upper Limit",
+                "Region 31 Sample Size",
+                "Region 31 Region Name",
+                "Region 31 Footnote",
+                "Region 32 Point Estimate",
+                "Region 32 Lower Limit",
+                "Region 32 Upper Limit",
+                "Region 32 Sample Size",
+                "Region 32 Region Name",
+                "Region 32 Footnote",
+                "Region 33 Point Estimate",
+                "Region 33 Lower Limit",
+                "Region 33 Upper Limit",
+                "Region 33 Sample Size",
+                "Region 33 Region Name",
+                "Region 33 Footnote",
+                "Region 34 Point Estimate",
+                "Region 34 Lower Limit",
+                "Region 34 Upper Limit",
+                "Region 34 Sample Size",
+                "Region 34 Region Name",
+                "Region 34 Footnote",
+            ]
+            rows = list(iterator)
+            assert rows[0][1:17] == [
+                "AFG",
+                "Afghanistan",
+                "SA",
+                "Asia",
+                "EMRO",
+                "Low Income",
+                "2004",
+                2004,
+                "NNS",
+                "Summary report of the national nutrition survey, 2004. Kabul, Islamic "
+                "Republic of Afghanistan: Ministry of Public Health and UNICEF, 2005.",
+                "Historical Trend",
+                "External Reanalysis",
+                3.5,
+                None,
+                None,
+                946,
+            ]
+            assert rows[-1][1:113] == [
+                "PSE",
+                "State of Palestine",
+                "MENA",
+                "Asia",
+                "Not Classified",
+                "Lower Middle Income",
+                "2014",
+                2014,
+                "MICS",
+                "Palestinian Multiple Indicator Cluster Survey 2014,  Final Report, Ramallah, "
+                "Palestine",
+                "Latest Source",
+                "Reanalyzed",
+                0.3240246,
+                0.2182891,
+                0.4807297,
+                6906.391,
+                None,
+                0.9850393,
+                0.3510135,
+                2.73288,
+                274.0501,
+                "Bethlehem",
+                None,
+                0.2285949,
+                0.0331941,
+                1.556335,
+                451.0902,
+                "Deir El-Balah",
+                None,
+                0,
+                0,
+                0,
+                1204.021,
+                "Gaza",
+                None,
+                0.379586,
+                0.1477162,
+                0.9718789,
+                963.5389,
+                "Hebron",
+                None,
+                0.9127916,
+                0.3687683,
+                2.241327,
+                414.6011,
+                "Jenin",
+                None,
+                0.9302664,
+                0.1729868,
+                4.841876,
+                75.54012,
+                "Jericho and Al Aghwar",
+                None,
+                1.340861,
+                0.6852518,
+                2.607252,
+                479.7003,
+                "Jerusalem",
+                None,
+                0,
+                0,
+                0,
+                645.629,
+                "Khan Yunis",
+                None,
+                0,
+                0,
+                0,
+                450.1119,
+                "Nablus",
+                None,
+                0.1555962,
+                0.022686,
+                1.058937,
+                657.3873,
+                "North Gaza",
+                None,
+                0.7926489,
+                0.1494378,
+                4.090945,
+                140.6539,
+                "Qalqiliya",
+                None,
+                0,
+                0,
+                0,
+                459.5546,
+                "Rafah",
+                None,
+                0.2857052,
+                0.040781,
+                1.97258,
+                331.3463,
+                "Ramallah & Al-Bireh",
+                None,
+                0,
+                0,
+                0,
+                97.44475,
+                "Salfit",
+                None,
+                0,
+                0,
+                0,
+                55.42068,
+                "Tubas",
+                None,
+                0.4782128,
+                0.0758192,
+                2.953107,
+                206.3006,
+                "Tulkarm",
+            ]
+
+    def test_get_tabular_rows_json(self, fixturejsonurl):
+        with Download() as downloader:
+            headers, iterator = downloader.get_tabular_rows(
+                fixturejsonurl, format="json"
+            )
+            assert headers == ["Country Code", "Country Name", "Population"]
+            assert list(iterator) == [
+                ["#country+code", "#country+name", "#population"],
+                ["AFG", "Afghanistan", 38041754],
+            ]
+
     def test_download_tabular_rows_as_dicts(self, fixtureprocessurl):
         with Download() as downloader:
             result = downloader.download_tabular_rows_as_dicts(
